%define upstream_name    Inline-Python
%define upstream_version 0.57

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Easy implementation of Python extensions
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Inline/%{upstream_name}-%{upstream_version}.tar.gz
#               Fix makefile logic
#               https://github.com/niner/inline-python-pm/pull/38
Patch0:         %{name}-makefile.patch
#               Improve compatibility with strict(er) C99 compilers
#               https://github.com/niner/inline-python-pm/pull/39
Patch1:         %{name}-c99.patch
#               Fix compiler warnings
#               https://github.com/niner/inline-python-pm/pull/41
Patch2:         %{name}-warn.patch
#               Fix compilation with Python 3.13
#               https://github.com/niner/inline-python-pm/pull/42
Patch3:         %{name}-py3.13.patch

BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Digest::MD5) >= 2.500.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Inline) >= 0.460.0
BuildRequires: perl(Proc::ProcessTable) >= 0.530.0
BuildRequires: perl(Test)
BuildRequires: perl(Test::Deep)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::Number::Delta)
BuildRequires: gcc
BuildRequires: findutils
BuildRequires: make
BuildRequires: perl-devel
BuildRequires: python3
BuildRequires: python3-devel
BuildConflicts: python2-devel
Requires:   perl(Inline) >= 0.460.0
Requires:   perl(Inline::denter)
%description
The 'Inline::Python' module allows you to put Python source code directly
"inline" in a Perl script or module. It sets up an in-process Python
interpreter, runs your code, and then examines Python's symbol table for
things to bind to Perl. The process of interrogating the Python interpreter
for globals only occurs the first time you run your Python code. The
namespace is cached, and subsequent calls use the cached version.

This document describes 'Inline::Python', the Perl package which gives you
access to a Python interpreter. For lack of a better place to keep it, it
also gives you instructions on how to use 'perlmodule', the Python package
which gives you access to the Perl interpreter.

%prep
%autosetup -n %{upstream_name}-%{upstream_version} -p1

%build
INLINE_PYTHON_EXECUTABLE=/usr/bin/python3 %{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}" NO_PACKLIST=1
%make_build

%install
%make_install

find %{buildroot} -type f -name '*.bs' -size 0 -delete

%{_fixperms} %{buildroot}/*

%check
make test

%files
%doc Changes META.json META.yml MYMETA.yml README TESTED
%{_mandir}/man3/*
%{perl_vendorarch}/Inline
%{perl_vendorarch}/auto/Inline


%changelog
* Tue Dec 19 2023 tv <tv> 0.570.0-3.mga10
+ Revision: 2019633
- Fix compiler warnings
- Port to C99
- Do not add LIBDIR to rpath
- Rebuild for perl-5.38
+ papoteur <papoteur>
- Mass Rebuild - Python 3.12

* Thu Sep 22 2022 tv <tv> 0.570.0-1.mga9
+ Revision: 1891562
- update to 0.57

* Tue Jun 07 2022 umeabot <umeabot> 0.560.0-16.mga9
+ Revision: 1862882
- Rebuild for Perl 5.36

* Sat Mar 19 2022 umeabot <umeabot> 0.560.0-15.mga9
+ Revision: 1799245
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 tv <tv> 0.560.0-14.mga9
+ Revision: 1782262
- Fix segmentation fault with python 3.10
- Rebuild for python-3.10

* Mon May 24 2021 umeabot <umeabot> 0.560.0-13.mga9
+ Revision: 1727685
- Rebuild for perl 5.34

* Sat Mar 20 2021 neoclust <neoclust> 0.560.0-12.mga9
+ Revision: 1706307
- Rebuild against python 3.9

* Thu Jun 18 2020 umeabot <umeabot> 0.560.0-11.mga8
+ Revision: 1595655
- Rebuild for perl 5.32

* Tue Feb 18 2020 umeabot <umeabot> 0.560.0-10.mga8
+ Revision: 1539640
- Mageia 8 Mass Rebuild

* Tue Dec 10 2019 shlomif <shlomif> 0.560.0-9.mga8
+ Revision: 1465639
- update URLs

* Sun Sep 22 2019 tv <tv> 0.560.0-8.mga8
+ Revision: 1444639
- rebuild for python-3.8

* Tue Aug 27 2019 tmb <tmb> 0.560.0-7.mga8
+ Revision: 1433702
- rebuild for perl 5.30

* Tue Jan 08 2019 tv <tv> 0.560.0-6.mga7
+ Revision: 1351700
- rebuild with python 3.7

* Fri Dec 28 2018 ngompa <ngompa> 0.560.0-5.mga7
+ Revision: 1345680
- Switch to use Python 3
- Fill out BuildRequires to be able to successfully run tests

* Fri Sep 21 2018 umeabot <umeabot> 0.560.0-4.mga7
+ Revision: 1293216
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.560.0-3.mga7
+ Revision: 1249789
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 0.560.0-2.mga7
+ Revision: 1165011
- rebuild with fixed rpm for missing autodeps

* Mon Sep 25 2017 tv <tv> 0.560.0-1.mga7
+ Revision: 1159774
- new release

* Thu Aug 31 2017 pterjan <pterjan> 0.490.0-5.mga7
+ Revision: 1149765
- Rebuild for perl ABI changes

* Sat Jul 22 2017 neoclust <neoclust> 0.490.0-4.mga7
+ Revision: 1126535
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.490.0-3.mga6
+ Revision: 1028587
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.490.0-2.mga6
+ Revision: 957541
- Mageia 6 Mass Rebuild

* Thu Jun 25 2015 sander85 <sander85> 0.490.0-1.mga6
+ Revision: 843154
- update to 0.49

* Wed Oct 15 2014 umeabot <umeabot> 0.450.0-3.mga5
+ Revision: 742044
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.450.0-2.mga5
+ Revision: 685135
- Mageia 5 Mass Rebuild

* Sat Sep 06 2014 sander85 <sander85> 0.450.0-1.mga5
+ Revision: 672890
- update to 0.45

* Wed Sep 03 2014 sander85 <sander85> 0.440.0-1.mga5
+ Revision: 671378
- update to 0.44

* Tue Jun 03 2014 pterjan <pterjan> 0.430.0-3.mga5
+ Revision: 631306
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.430.0-2.mga4
+ Revision: 534571
- Mageia 4 Mass Rebuild

* Fri Sep 13 2013 sander85 <sander85> 0.430.0-1.mga4
+ Revision: 478450
- update to 0.43

* Sun Jun 02 2013 jquelin <jquelin> 0.420.0-1.mga4
+ Revision: 434550
- update to 0.42
- reverting patch
- fix non-zero wait status during tests
+ tv <tv>
- rebuild for new perl

* Sun Jan 13 2013 umeabot <umeabot> 0.410.0-2.mga3
+ Revision: 368745
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 14 2012 jquelin <jquelin> 0.410.0-1.mga3
+ Revision: 317680
- update to 0.41

* Wed May 30 2012 jquelin <jquelin> 0.400.0-2.mga3
+ Revision: 250780
- rebuild for perl 5.16
- update to 0.40

* Sun Jun 12 2011 sander85 <sander85> 0.390.0-2.mga2
+ Revision: 105310
- fix test
- Rebuild for perl 5.14

* Sun Mar 13 2011 jquelin <jquelin> 0.390.0-1.mga1
+ Revision: 70532
- update to 0.39
- mageia rebuild
- imported package perl-Inline-Python

